@@ -667,9 +667,9 @@ gsf_outfile_msole_class_init (GObjectClass *gobject_class)
 	gsf_output_class = g_type_class_peek (GSF_OUTPUT_TYPE);
 }
 
-GSF_DYNAMIC_CLASS (GsfOutfileMSOle, gsf_outfile_msole,
-		   gsf_outfile_msole_class_init, gsf_outfile_msole_init,
-		   GSF_OUTFILE_TYPE)
+GSF_CLASS (GsfOutfileMSOle, gsf_outfile_msole,
+	   gsf_outfile_msole_class_init, gsf_outfile_msole_init,
+	   GSF_OUTFILE_TYPE)
 
 /* returns the number of times 1 must be shifted left to reach value */
 static unsigned
@@ -712,6 +712,8 @@ gsf_outfile_msole_new_full (GsfOutput *sink, guint bb_size, guint sb_size)
 	g_return_val_if_fail (GSF_IS_OUTPUT (sink), NULL);
 
 	ole = g_object_new (GSF_OUTFILE_MSOLE_TYPE, NULL);
+	if (G_UNLIKELY (NULL == ole)) return NULL;
+
 	g_object_ref (G_OBJECT (sink));
 	ole->sink = sink;
 	ole->type = MSOLE_DIR;
