@@ -99,16 +99,18 @@ gsf_outfile_stdio_class_init (GObjectClass *gobject_class)
 	outfile_class->new_child = gsf_outfile_stdio_new_child;
 }
 
-GSF_DYNAMIC_CLASS (GsfOutfileStdio, gsf_outfile_stdio,
-		   gsf_outfile_stdio_class_init, gsf_outfile_stdio_init,
-		   GSF_OUTFILE_TYPE)
+GSF_CLASS (GsfOutfileStdio, gsf_outfile_stdio,
+	   gsf_outfile_stdio_class_init, gsf_outfile_stdio_init,
+	   GSF_OUTFILE_TYPE)
 
 /**
- * gsf_outfile_stdio_new :
+ * gsf_outfile_stdio_new_valist :
  * @root : root directory in utf8.
  * @err	 : optionally NULL.
+ * @first_property_name: name of first property to set
+ * @var_args: a %NULL-terminated #va_list
  *
- * Returns a new outfile or NULL.
+ * Returns: a new outfile or NULL.
  **/
 GsfOutfile *
 gsf_outfile_stdio_new_valist (char const *root, GError **err,
@@ -137,9 +139,19 @@ gsf_outfile_stdio_new_valist (char const *root, GError **err,
 	return GSF_OUTFILE (ofs);
 }
 
+/**
+ * gsf_outfile_stdio_new_full :
+ * @root : root directory in utf8.
+ * @err	 : optionally NULL.
+ * @first_property_name: name of first property to set
+ * @Varargs: value of first property, followed by more properties,
+ * 		%NULL-terminated
+ *
+ * Returns: a new outfile or NULL.
+ **/
 GsfOutfile *
 gsf_outfile_stdio_new_full (char const *root, GError **err,
-			    const gchar    *first_property_name,
+			    gchar const *first_property_name,
 			    ...)
 {
 	GsfOutfile *res;
@@ -157,7 +169,7 @@ gsf_outfile_stdio_new_full (char const *root, GError **err,
  * @root : root directory in utf8.
  * @err	 : optionally NULL.
  *
- * Returns a new outfile or NULL.
+ * Returns: a new outfile or NULL.
  **/
 GsfOutfile *
 gsf_outfile_stdio_new (char const *root, GError **err)
